OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Txertatutako mezua %s",
    "Important mail" : "Posta garrantzitsua",
    "No message found yet" : "Ez da mezurik aurkitu oraindik.",
    "Set up an account" : "Konfiguratu kontu bat",
    "Unread mail" : "Irakurri gabeko posta",
    "Important" : "Garrantzitsua",
    "Work" : "Lana",
    "Personal" : "Pertsonala",
    "To Do" : "Egiteke",
    "Later" : "Beranduago",
    "Mail" : "Posta",
    "You are reaching your mailbox quota limit for {account_email}" : "{account_email} konturako postontziaren kuota-mugara heltzen ari zara",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Zure postontziaren biltegiaren {percentage} erabiltzen ari zara une honetan. Mesedez, egin ezazu lekua behar ez dituzun postak ezabatuz.",
    "Mail Application" : "Mail aplikazioa",
    "Mails" : "Posta",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following email: %3$s" : "%1$s email bidaltzailea ez dago helbide liburuan, baina %2$s izeneko bidaltzailea badago helbide liburuan, %3$s emailarekin",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following emails: %3$s" : "%1$s email bidaltzailea ez dago helbide liburuan, baina %2$s izeneko bidaltzailea badago helbide liburuan, %3$s emailekin.",
    "Sender is using a custom email: %1$s instead of the sender email: %2$s" : "Bidaltzailea %1$s email pertsonalizatua erabiltzen ari da, %2$s emailetik beharrean.",
    "Sent date is in the future" : "Bidaltze data etorkizunekoa da",
    "Some addresses in this message are not matching the link text" : "Mezu honetako helbide batzuk ez datoz bat estekako testuarekin",
    "💌 A mail app for Nextcloud" : "💌 Posta elektroniko zerbitzu bat Nextcloudekin",
    "Your session has expired. The page will be reloaded." : "Zure saioa iraungi da. Orria berriro kargatuko da.",
    "Drafts are saved in:" : "Zirriborroak hemen gordetzen dira:",
    "Sent messages are saved in:" : "Bidalitako mezuak hemen gordetzen dira:",
    "Deleted messages are moved in:" : "Ezabatutako mezuak hona mugitzen dira:",
    "Archived messages are moved in:" : "Artxibatutako mezuak hona mugitzen dira:",
    "Snoozed messages are moved in:" : "Geroko utzitako mezuak hona mugitzen dira:",
    "Junk messages are saved in:" : "Zabor mezuak hemen gordetzen dira:",
    "Connecting" : "Konektatzen",
    "Reconnect Google account" : "Konektatu berriro Google kontua",
    "Sign in with Google" : "Hasi saioa Google-rekin",
    "Reconnect Microsoft account" : "Berriro konektatu Microsoft kontuarekin",
    "Sign in with Microsoft" : "Hasi saioa Microsoft-ekin",
    "Save" : "Gorde",
    "Connect" : "Konektatu",
    "Looking up configuration" : "Konfigurazioa begiratzen",
    "Checking mail host connectivity" : "Mail ostalariaren konektibitatea egiaztatzen",
    "Configuration discovery failed. Please use the manual settings" : "Konfigurazioaren ezagutzak huts egin du. Erabili eskuzko ezarpenak mesedez",
    "Password required" : "Pasahitza beharrezkoa da",
    "Testing authentication" : "Autentifikazioa probatzen",
    "Awaiting user consent" : "Erabiltzailearen onarpenaren zain",
    "Account created. Please follow the pop-up instructions to link your Google account" : "Kontua sortu da. Mesedez, jarraitu popup-aren jarraibideak zure Google kontua estekatzeko",
    "Account created. Please follow the pop-up instructions to link your Microsoft account" : "Erabiltzailea sortu da. Jarraitu pop-up jarraibideei zure Microsoft kontuarekin lotura egiteko",
    "Loading account" : "Kontua kargatzen",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Kontua eguneratu da. Mesedez, jarraitu popup-aren jarraibideak zure Google kontua berriro konektatzeko",
    "Account updated. Please follow the pop-up instructions to reconnect your Microsoft account" : "Erabiltzailea eguneratu da. Jarraitu pop-up jarraibideei zure Microsoft kontuarekin berriro konektatzeko",
    "Account updated" : "Kontua eguneratu da",
    "IMAP server is not reachable" : "IMAP zerbitzaria ezin da atzitu",
    "SMTP server is not reachable" : "SMTP zerbitzaria ezin da atzitu",
    "IMAP username or password is wrong" : "IMAP erabiltzaile edo pasahitza txarto dago",
    "SMTP username or password is wrong" : "SMTP erabiltzaile edo pasahitza txarto dago",
    "IMAP connection failed" : "IMAP konexioak huts egin du",
    "SMTP connection failed" : "SMTP konexioak huts egin du",
    "Authorization pop-up closed" : "Baimenaren pop-up itxi da",
    "Configuration discovery temporarily not available. Please try again later." : "Konfigurazioaren aurkikuntza aldi baterako ez dago erabilgarri. Saiatu berriro geroago.",
    "There was an error while setting up your account" : "Errore bat gertatu da zure kontua konfiguratzean",
    "Auto" : "Auto",
    "Name" : "Izena",
    "Mail address" : "Helbide elektronikoa",
    "name@example.org" : "izena@adibidea.org",
    "Please enter an email of the format name@example.com" : "Mesedez, sartu name@example.com formatuko mezu elektroniko bat",
    "Password" : "Pasahitza",
    "Manual" : "Eskuz",
    "IMAP Settings" : "IMAP ezarpenak",
    "IMAP Host" : "IMAP ostalaria",
    "IMAP Security" : "IMAP segurtasuna",
    "None" : "Bat ere ez",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP ataka",
    "IMAP User" : "IMAP erabiltzailea",
    "IMAP Password" : "IMAP pasahitza",
    "SMTP Settings" : "SMTP ezarpenak",
    "SMTP Host" : "SMTP ostalaria",
    "SMTP Security" : "SMTP segurtasuna",
    "SMTP Port" : "SMTP ataka",
    "SMTP User" : "SMTP erabiltzailea",
    "SMTP Password" : "SMTP pasahitza",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Google-ko kontuak aplikazio honekin funtziona dezan, Google-n bi faktoreko autentifikazioa gaitu eta aplikazioaren pasahitza sortu behar duzu.",
    "Account settings" : "Kontuaren ezarpenak",
    "Aliases" : "Aliasak",
    "Alias to S/MIME certificate mapping" : "S/MIME ziurtagiriaren esleipenerako aliasa",
    "Signature" : "Sinadura",
    "A signature is added to the text of new messages and replies." : "Sinadura bat gehitzen zaio mezu berri eta erantzunen testuari.",
    "Writing mode" : "Editatzeko aukera gaituta",
    "Preferred writing mode for new messages and replies." : "Hobetsitako idazteko modua, mezu berri eta erantzunak idazteko.",
    "Default folders" : "Lehenetsitako karpetak",
    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "Zirriborro, bidalitako, ezabatutako, artxibatutako eta zabor mezuentzako erabilitako karpeta.",
    "Automatic trash deletion" : "Zaborraren ezabatze automatikoa",
    "Days after which messages in Trash will automatically be deleted:" : "Zaborrontziko mezuak automatikoki ezabatuko dira hainbat egunen ostean:",
    "Autoresponder" : "Autoerantzulea",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Sarrerako mezuei erantzun automatikoa. Norbaitek hainbat mezu bidaltzen badizu, erantzun automatizatu hau gehienez 4 egunean behin bidaliko da.",
    "Calendar settings" : "Egutegiaren ezarpenak",
    "Filters" : "Iragazkiak",
    "Sieve script editor" : "Sieve script editorea",
    "Mail server" : "Posta-zerbitzaria",
    "Sieve server" : "Sieve zerbitzaria",
    "Update alias" : "Eguneratu aliasa",
    "Rename alias" : "Aliasa berrizendatu",
    "Show update alias form" : "Erakutsi alias inprimakiaren eguneratzea",
    "Delete alias" : "Ezabatu aliasa",
    "Go back" : "Egin atzera",
    "Change name" : "Aldatu izena",
    "Email address" : "Helbide elektronikoa",
    "Add alias" : "Gehitu aliasa",
    "Create alias" : "Sortu aliasa",
    "Cancel" : "Utzi",
    "Activate" : "Aktibatu",
    "Remind about messages that require a reply but received none" : "Oroitarazi erantzun bat behar zuten baina jaso ez zuten mezuak",
    "Could not update preference" : "Ezin izan da hobespena eguneratu",
    "Mail settings" : "Posta ezarpenak",
    "General" : "Orokorra",
    "Add mail account" : "Gehitu posta-kontua",
    "Appearance" : "Itxura",
    "Layout" : "Diseinua",
    "Vertical split" : "Banaketa bertikala",
    "Horizontal split" : "Banaketa horizontala",
    "List" : "Zerrenda",
    "Sorting" : "Antolaketa",
    "Newest first" : "Berrienak lehenengo ",
    "Oldest first" : "Zaharrenak lehenengo",
    "Shared with me" : "Nirekin partekatuta",
    "Privacy" : "Pribatutasuna",
    "Security" : "Segurtasuna",
    "S/MIME" : "S/MIME",
    "Manage certificates" : "Kudeatu ziurtagiriak",
    "Mailvelope" : "Mailvelope",
    "Assistance features" : "Laguntzailearen aukerak",
    "About" : "Honi buruz",
    "Compose new message" : "Idatzi mezu berria",
    "Newer message" : "Mezu berriagoa",
    "Older message" : "Mezu zaharragoa",
    "Toggle star" : "Txandakatu izarra",
    "Toggle unread" : "Txandakatu irakurri gabea",
    "Archive" : "Artxibatu",
    "Delete" : "Ezabatu",
    "Search" : "Bilatu",
    "Send" : "Bidali",
    "Refresh" : "Freskatu",
    "Ok" : "Ados",
    "No certificate" : "Ziurtagiririk ez",
    "Certificate updated" : "Ziurtagiria eguneratu da",
    "Could not update certificate" : "Ezin izan da ziurtagiria eguneratu",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - baliozkoa {expiryDate} arte",
    "Select an alias" : "Hautatu alias bat",
    "Select certificates" : "Hautatu ziurtagiriak",
    "Update Certificate" : "Eguneratu ziurtagiria",
    "The selected certificate is not trusted by the server. Recipients might not be able to verify your signature." : "Hautatutako ziurtagiria zerbitzariak ez du fidagarritzat hartu. Baliteke hartzaileek ezin zure sinadura egiaztatu.",
    "Encrypt with S/MIME and send later" : "Enkriptatu S/MIME-rekin eta bidali geroago",
    "Encrypt with S/MIME and send" : "Enkriptatu S/MIME-rekin eta bidali",
    "Encrypt with Mailvelope and send later" : "Enkriptatu Mailvelope-rekin eta bidali geroago",
    "Encrypt with Mailvelope and send" : "Enkriptatu Mailvelope-rekin eta bidali",
    "Send later" : "Bidali geroago",
    "Message {id} could not be found" : "Ezin izan da {id} mezua aurkitu",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "S/MIME-rekin sinatu edo enkriptatu hautatu da, baina ez dugu hautatutako aliasaren ziurtagiririk. Mezua ez da sinatuko edo enkriptatuko.",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Lehendik dagoen edozein formatua (adibidez, lodia, etzana, azpimarra edo lerroan dauden irudiak) kenduko da.",
    "Turn off formatting" : "Itzali formateatzea",
    "Turn off and remove formatting" : "Itzali eta kendu formateatzea",
    "Keep formatting" : "Mantendu formateatzea",
    "From" : "Nork",
    "Select account" : "Hautatu kontua",
    "To" : "Nori",
    "Cc/Bcc" : "Cc/Bcc",
    "Select recipient" : "Hautatu hartzailea",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "Gaia",
    "This message came from a noreply address so your reply will probably not be read." : "Mezu hau noreply helbide batetik dator, beraz, ziur aski, zure erantzuna ez dute irakurriko.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "Hartzaile hauek ez dute S/MIME ziurtagiririk: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : " \nHartzaile hauek ez dute PGP gakorik: {recipients}.",
    "Error saving draft" : "Errore bat gertatu da zirriborroa gordetzean",
    "Draft saved" : "Zirriborroa gorde egin da",
    "Save draft" : "Gorde zirriborroa",
    "Discard & close draft" : "Baztertu eta itxi zirriborroa",
    "Enable formatting" : "Gaitu formateatzea",
    "Disable formatting" : "Desgaitu formateatzea",
    "Upload attachment" : "Igo eranskina",
    "Add attachment from Files" : "Gehitu eranskina Fitxategiak-etik",
    "Add share link from Files" : "Gehitu partekatze esteka Fitxategiak-etik",
    "Smart picker" : "Hautatzaile adimenduna",
    "Request a read receipt" : "Eskatu irakurriagiria",
    "Sign message with S/MIME" : "Sinatu mezua S/MIME-rekin",
    "Encrypt message with S/MIME" : "Enkriptatu mezua S/MIME-rekin",
    "Encrypt message with Mailvelope" : "Zifratu mezua Mailvelopekin",
    "Send now" : "Bidali orain",
    "Tomorrow morning" : "Bihar goizean",
    "Tomorrow afternoon" : "Bihar arratsaldean",
    "Monday morning" : "Astelehen goizean",
    "Custom date and time" : "Data eta ordu pertsonalizatuak",
    "Enter a date" : "Sartu data bat",
    "Choose" : "Aukeratu",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Eranskinek baimendutako {size} -ko eranskin tamaina gainditzen du. Partekatu fitxategia esteka bidez horren ordez.","Eranskinek baimendutako {size} -ko eranskin tamaina gainditzen du. Partekatu fitxategia esteka bidez horren ordez."],
    "Choose a file to add as attachment" : "Aukeratu fitxategia eranskin gisa gehitzeko",
    "Choose a file to share as a link" : "Aukeratu fitxategi bat esteka bezala partekatzeko",
    "_{count} attachment_::_{count} attachments_" : ["Eranskin {count}","{count} eranskin"],
    "Untitled message" : "Izenik gabeko mezua",
    "Expand composer" : "Hedatu egilea",
    "Close composer" : "Itxi egilea",
    "Confirm" : "Berretsi",
    "Tag: {name} deleted" : "Etiketa: {name} ezabatuta",
    "An error occurred, unable to delete the tag." : "Errore bat gertatu da, ezin izan da etiketa ezabatu.",
    "The tag will be deleted from all messages." : "Mezu guztietako etiketak ezabatuko dira.",
    "Plain text" : "Testu arrunta",
    "Rich text" : "Testu aberastua",
    "No messages in this folder" : "Mezurik ez karpeta honetan",
    "No messages" : "Mezurik ez",
    "Blind copy recipients only" : "Kopia itsuen jasotzaileek besterik ez",
    "No subject" : "Gairik ez",
    "Later today – {timeLocale}" : "Beranduago gaur – {timeLocale}",
    "Set reminder for later today" : "Ezarri gogorarazpena gaur beranduagorako",
    "Tomorrow – {timeLocale}" : "Bihar – {timeLocale}",
    "Set reminder for tomorrow" : "Ezarri gogorarazpena biharko",
    "This weekend – {timeLocale}" : "Hurrengo asteburua – {timeLocale}",
    "Set reminder for this weekend" : "Ezarri gogorarazpena asteburu honetarako",
    "Next week – {timeLocale}" : "Hurrengo astea – {timeLocale}",
    "Set reminder for next week" : "Ezarri gogorarazpena hurrengo asterako",
    "Could not delete message" : "Ezin izan da mezua ezabatu",
    "Could not archive message" : "Ezin izan da mezua artxibatu",
    "Thread was snoozed" : "Haria geroko utzi da",
    "Could not snooze thread" : "Haria ezin izan da geroko utzi",
    "Thread was unsnoozed" : "Hariari geroko uztea kendu zaio",
    "Could not unsnooze thread" : "Ezin izan da kendu hariaren atzerapena ",
    "Encrypted message" : "Zifratutako mezua",
    "This message is unread" : "Mezu hau irakurri gabe dago",
    "Unfavorite" : "Kendu gogokoetatik",
    "Favorite" : "Egin gogoko",
    "Unread" : "Irakurri gabe",
    "Read" : "Irakurri",
    "Unimportant" : "Garrantzi gabekoa",
    "Mark not spam" : "Markatu ez spam gisa",
    "Mark as spam" : "Markatu spam gisa",
    "Edit tags" : "Editatu etiketak",
    "Snooze" : "Geroko utzi",
    "Unsnooze" : "Ez utzi geroko",
    "Move thread" : "Mugitu haria",
    "Archive thread" : "Artxibatu haria",
    "Archive message" : "Artxibatu mezua",
    "Delete thread" : "Ezabatu haria",
    "Delete message" : "Mezua ezabatzen",
    "More actions" : "Ekintza gehiago",
    "Back" : "Atzera",
    "Set custom snooze" : "Ezarri atzerapen pertsonalizatua",
    "Edit as new message" : "Aldatu mezu berri gisa",
    "Create task" : "Sortu zeregina",
    "Download message" : "Deskargatu mezua",
    "Load more" : "Kargatu gehiago",
    "_Mark {number} read_::_Mark {number} read_" : [" 100% match \nMarkatu {number} irakurrita bezala","Markatu {number} irakurrita bezala"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Markatu {number} irakurri gabe bezala","Markatu {number} irakurri gabe bezala"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Markatu {number} garrantzizko","Markatu {number} garrantzizko"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Markatu {number} garrantzi gabe","Markatu {number} garrantzi gabe"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Kendu gogokoetatik {number}","Kendu gogokoetatik  {number}"],
    "_Favorite {number}_::_Favorite {number}_" : ["Gogokoa {number}","Gogokoa {number}"],
    "_Unselect {number}_::_Unselect {number}_" : ["Desautatu {number}","Desautatu {number}"],
    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Markatu {number} zabor gisa","Markatu {number} zabor gisa"],
    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["Markatu {number} ez zabor gisa","Markatu {number} ez zabor gisa"],
    "_Edit tags for {number}_::_Edit tags for {number}_" : ["Editatu {number}-en etiketak","Editatu  {number}-ren etiketak"],
    "_Move {number} thread_::_Move {number} threads_" : ["Mugitu hari {number}","Mugitu {number} hari"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Birbidali {zenbakia} eranskin bezala","Birbidali {zenbakia} eranskin bezala"],
    "Mark as unread" : "Markatu ez irakurritako gisa",
    "Mark as read" : "Markatu irakurritako gisa",
    "Mark as important" : "Markatu garrantzizko gisa",
    "Report this bug" : "Eman errore honen berri",
    "Event created" : "Sortu da gertaera",
    "Could not create event" : "Ezin izan da gertaera sortu",
    "Create event" : "Sortu gertaera",
    "All day" : "Egun osoa",
    "Attendees" : "Partaideak",
    "Select calendar" : "Hautatu egutegia",
    "Description" : "Deskripzioa",
    "Create" : "Sortu",
    "This event was updated" : "Gertaera hau eguneratu da",
    "{attendeeName} accepted your invitation" : "{attendeeName}(e)k zure gonbidapena onartu du",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName}(e)k zure gonbidapena behin-behinean onartu du",
    "{attendeeName} declined your invitation" : "{attendeeName}(e)k zure gonbidapenari uko egin dio",
    "{attendeeName} reacted to your invitation" : "{attendeeName} gonbidapen honi buruz erreakzionatu du dagoeneko",
    "Failed to save your participation status" : "Ezin izan da gorde zure parte-hartze egoera",
    "You accepted this invitation" : "Gonbidapen hau onartu duzu",
    "You tentatively accepted this invitation" : "Gonbidapen hau behin-behinean onartu duzu",
    "You declined this invitation" : "Gonbidapen hau baztertu duzu",
    "You already reacted to this invitation" : "Gonbidapen honi buruz erreakzionatu duzu dagoeneko",
    "You have been invited to an event" : "Gertaera batera gonbidatu zaituzte",
    "This event was cancelled" : "Gertaera hau bertan behera utzi da",
    "Save to" : "Gorde hona:",
    "Select" : "Hautatu",
    "Comment" : "Iruzkindu",
    "Accept" : "Onartu",
    "Decline" : "Uko egin",
    "Tentatively accept" : "Behin-behinean onartu",
    "More options" : "Aukera gehiago",
    "Could not remove internal address {sender}" : "Ezin izan da {sender} barneko helbidea kendu",
    "Could not add internal address {address}" : "Ezin izan da {address}barneko helbidea gehitu",
    "individual" : "bakarkakoa",
    "domain" : "domeinua",
    "Remove" : "Kendu",
    "Add internal address" : "Gehitu barneko helbidea",
    "Add internal email or domain" : "Gehitu barneko helbide elektronikoa edo domeinua",
    "Itinerary for {type} is not supported yet" : "{type} motarentzako ibilbidea ez da onartzen oraindik",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Ez duzu mezu hau artxibo karpetara eramateko eta/edo mezu hau uneko karpetatik ezabatzeko baimenik",
    "Last hour" : "Azken ordua",
    "Today" : "Gaur",
    "Last week" : "Joan den astean",
    "Last month" : "Joan den hilabetean",
    "Choose target folder" : "Aukeratu helburuko karpeta",
    "No more submailboxes in here" : "Azpipostontzi gehiagorik ez hemen",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Mezuak automatikoki markatuko dira garrantzitsu bezala kontuan izanda zein mezurekin aritu zaren interakzioan edo zein markatu dituzun garratzitsu gisa. Hasieran garrantzia eskuz aldatu beharko duzu sistemari irakasteko, baina denborarekin hobetuko du.",
    "Messages sent by you that require a reply but did not receive one after a couple of days will be shown here." : "Erantzuteko eskatuz bidali zenituen emailak, baina egun batzuen ondoren erantzunik jasotzen ez dutenak hemen erakutsiko dira.",
    "Favorites" : "Gogokoak",
    "Follow up" : "Segimendua egin",
    "Follow up info" : "Segimenduaren informazioa",
    "Important info" : "Informazio garrantzitsua",
    "Other" : "Beste bat",
    "Could not send mdn" : "Ezin izan da mdn bidali",
    "The sender of this message has asked to be notified when you read this message." : "Mezu honen igorleak mezu hau irakurtzean jakinaraztea eskatu du.",
    "Notify the sender" : "Jakinarazi bidaltzaileari",
    "You sent a read confirmation to the sender of this message." : "Irakurtze-berrespena bidali diozu mezu honen igorleari.",
    "Message was snoozed" : "Mezua geroko utzi da",
    "Could not snooze message" : "Ezin izan da mezua geroko utzi",
    "Message was unsnoozed" : "Mezuari geroko uztea kendu zaio",
    "Could not unsnooze message" : "Ezin izan zaio kendu atzerapena mezuari",
    "Forward" : "Birbidali",
    "Move message" : "Mugitu mezua",
    "Translate" : "Itzuli",
    "Forward message as attachment" : "Birbidali mezua eranskin gisa",
    "View source" : "Ikusi iturburua",
    "Print message" : "Inprimatu mezua",
    "Download thread data for debugging" : "Deskargatu hariaren datuak arazteko",
    "Message body" : "Mezuaren gorputza",
    "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Abisua: mezu honen S/MIME sinadura egiaztatu gabe dago. Baliteke igorleak norbaiten nortasuna ordezkatzea!",
    "Unnamed" : "Izen gabekoa",
    "Embedded message" : "Kapsulatutako mezua",
    "Attachment saved to Files" : "Eranskina Fitxategiak-en gorde da",
    "Attachment could not be saved" : "Ezin izan da eranskina gorde",
    "calendar imported" : "egutegia inportatuta",
    "Choose a folder to store the attachment in" : "Aukeratu karpeta bat eranskina gordetzeko",
    "Import into calendar" : "Inportatu egutegira",
    "Download attachment" : "Deskargatu eranskina",
    "Save to Files" : "Gorde Fitxategiak-en",
    "Attachments saved to Files" : "Eranskinak ondo gorde dira Fitxategietan",
    "Error while saving attachments" : "Errorea eranskinak gordetzean",
    "View fewer attachments" : "Ikusi eranskin gutxiago",
    "Choose a folder to store the attachments in" : "Aukeratu karpeta bat erantsitako fitxategiak gordetzeko",
    "Save all to Files" : "Gorde dena Fitxategiak-en",
    "Download Zip" : "Deskargatu Zip",
    "_View {count} more attachment_::_View {count} more attachments_" : ["Ikusi eranskin {count} gehiago","Ikusi {count} eranskin gehiago"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : " \nMezu hau PGP bidez enkriptatu da. Instalatu Mailvelope desenkriptatzeko.",
    "The images have been blocked to protect your privacy." : "Irudiak blokeatu dira zure pribatutasuna babesteko.",
    "Show images" : "Erakutsi irudiak",
    "Show images temporarily" : "Erakutsi irudiak aldi baterako",
    "Always show images from {sender}" : "Erakutsi beti {sender} erabiltzailearen irudiak",
    "Always show images from {domain}" : "Erakutsi beti {domain} domeinuko irudiak",
    "Message frame" : "Mezuaren enkoadraketa",
    "Quoted text" : "Aipatutako testua",
    "Move" : "Mugitu",
    "Moving" : "Mugitzen",
    "Moving thread" : "Haria mugitzen",
    "Moving message" : "Mezua mugitzen",
    "Remove account" : "Kendu kontua",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "{email} kontua eta cachean gordetako posta datuak Nextcloudetik ezabatu egingo dira, baina ez zure posta hornitzailetik.",
    "Remove {email}" : "Kendu {email}",
    "Provisioned account is disabled" : "Hornitutako kontua desgaituta dago",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Mesedez, hasi saioa pasahitz bat erabiliz kontu hau gaitzeko. Uneko saioa pasahitzik gabeko autentifikazioa erabiltzen ari da, adibidez. SSO edo WebAuthn.",
    "Show only subscribed folders" : "Erakutsi harpidetutako karpetak soilik",
    "Add folder" : "Gehitu karpeta",
    "Folder name" : "Karpetaren izena",
    "Saving" : "Gordetzen",
    "Move up" : "Eraman gora",
    "Move down" : "Eraman behera",
    "Show all subscribed folders" : "Erakutsi harpidetutako karpeta guztiak",
    "Show all folders" : "Erakutsi karpeta guztiak",
    "Collapse folders" : "Bildu karpetak",
    "_{total} message_::_{total} messages_" : ["Mezu {total}","{total} mezu"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} irakurri gabe {total} -etik","{unread} irakurri gabe {total} -etik"],
    "Loading …" : "Kargatzen …",
    "All messages in mailbox will be deleted." : "Postontziko mezu guztiak ezabatuko dira.",
    "Clear mailbox {name}" : "Garbitu {name} postontzia",
    "The folder and all messages in it will be deleted." : " \nKarpeta eta bertan dauden mezu guztiak ezabatuko dira.",
    "Delete folder" : "Ezabatu karpeta",
    "Delete folder {name}" : "Ezabatu {name} karpeta ",
    "An error occurred, unable to rename the mailbox." : "Akatsen bat gertatu da, ezin izan da postontzia berrizendatu.",
    "Please wait 10 minutes before repairing again" : "Mesedez, itxaron 10 minutu berriro konpondu aurretik",
    "Mark all as read" : "Markatu dena irakurrita bezala",
    "Add subfolder" : "Gehitu azpi-karpeta bat",
    "Rename" : "Berrizendatu",
    "Move folder" : "Lekuz aldatu karpeta",
    "Clear cache" : "Garbitu cachea",
    "Clear locally cached data, in case there are issues with synchronization." : "Ezabatu lokalean katxeatutako datuak, sinkronizaziorik arazorik badagoen.",
    "Subscribed" : "Harpidetua",
    "Sync in background" : "Sinkronizatu atzealdean",
    "Outbox" : "Irteera-postontzia",
    "New message" : "Mezu berria",
    "Edit message" : "Editatu mezua",
    "Draft" : "Zirriborroa",
    "Reply" : "Erantzun",
    "Message saved" : "Mezua gordeta",
    "Failed to save message" : "Mezua gordetzeak huts egin du",
    "Failed to save draft" : "Zirriborroa gordetzeak huts egin du",
    "attachment" : "eranskina",
    "attached" : "erantsita",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "To eta / edo Cc-n hartzaile askori bidaltzen saiatzen ari zara. Hartzaileen helbideak ezkutatzeko Bcc erabili dezakezu.",
    "You mentioned an attachment. Did you forget to add it?" : "Eranskin bat aipatu duzu. Gehitzea ahaztu al zaizu?",
    "Message discarded" : "Mezua bertan behera utzi da",
    "Could not discard message" : "Ezin izan da mezua baztertu",
    "Maximize composer" : "Maximizatu prestatzailea",
    "Minimize composer" : "minimizatu egilea",
    "Error sending your message" : "Errorea zure mezua bidaltzerakoan",
    "Retry" : "Saiatu berriro",
    "Warning sending your message" : "Abisua zure mezua bidaltzerakoan",
    "Send anyway" : "Bidali nolanahi ere",
    "Autoresponder off" : "Autoerantzulea itzalita",
    "Autoresponder on" : "Autoerantzulea piztuta",
    "Autoresponder follows system settings" : "Erantzun automatikoek sistemaren ezarpenak jarraitzen dituzte",
    "The autoresponder follows your personal absence period settings." : "Erantzun automatikoek zure absentzia-epearen ezarpen pertsonalak jarraitzen dituzte.",
    "Edit absence settings" : "Editatu absentzia ezarpenak",
    "First day" : "Lehen eguna",
    "Last day (optional)" : "Azken eguna (aukerazkoa)",
    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} erantzuten ari zaren mezuaren gaiarekin ordezkatuko da",
    "Message" : "Mezua",
    "Oh Snap!" : "Hara!",
    "Save autoresponder" : "Gorde autoerantzulea",
    "Could not open outbox" : "Ezin izan da irteera-postontzia ireki",
    "Pending or not sent messages will show up here" : "Bidali gabe dauden edo bidali gabeko mezuak hemen agertuko dira",
    "Mail server error" : "Posta zerbitzariaren errorea",
    "Message could not be sent" : "Ezin izan da mezua bidali",
    "Message deleted" : "Mezua ezabatu da",
    "Phishing email" : "Pishing emaila",
    "This email might be a phishing attempt" : "Posta elektroniko hau phishing saiakera bat izan daiteke",
    "Hide suspicious links" : "Ezkutatu esteka susmagarriak",
    "Show suspicious links" : "Erakutsi esteka susmagarriak",
    "link text" : "esteka-testua",
    "Copied email address to clipboard" : "e-posta helbidea arbelera kopiatu da",
    "Could not copy email address to clipboard" : "Ezin izan da e-posta helbidea arbelera kopiatu",
    "Contacts with this address" : "Kontaktuak helbidearekin",
    "Add to Contact" : "Gehitun kontaktuetara",
    "New Contact" : "Kontaktu berria",
    "Copy to clipboard" : "Kopiatu arbelera",
    "Add" : "Gehitu",
    "Show less" : "Erakutsi gutxiago",
    "Show more" : "Erakutsi gehiago",
    "Clear" : "Garbitu",
    "Close" : "Itxi",
    "Search parameters" : "Bilaketa parametroak",
    "Search subject" : "Bilatu gaian",
    "Body" : "Gorputza",
    "Search body" : "Bilatu testuan",
    "Date" : "Data",
    "Pick a start date" : "Aukeratu hasiera-data",
    "Pick an end date" : "Aukeratu amaiera-data",
    "Select senders" : "Hautatu bidaltzaileak",
    "Select recipients" : "Hautatu hartzaileak",
    "Select CC recipients" : "Hautatu CC hartzaileak",
    "Select BCC recipients" : "Hautatu BCC hartzaileak",
    "Tags" : "Etiketak",
    "Select tags" : "Hautatu etiketak",
    "Marked as" : "Honela markatuta:",
    "Has attachments" : "Eranskinak ditu",
    "Mentions me" : "Ni aipatzen nau",
    "Has attachment" : "Eranskina dauka",
    "Enable mail body search" : "Gaitu posten testuko bilaketa",
    "Sieve is a powerful language for writing filters for your mailbox. You can manage the sieve scripts in Mail if your email service supports it. Sieve is also required to use Autoresponder and Filters." : "Sieve zure postontzirako iragazkiak idazteko hizkuntza indartsua da. Posta elektronikoko gidoiak kudea ditzakezu. Sieve ere behar da Auto-erantzule eta Iragazkiak erabiltzeko.",
    "Enable sieve filter" : "Gaitu sieve iragazkia",
    "Sieve host" : "Sieve ostalaria",
    "Sieve security" : "Sieve segurtasuna",
    "Sieve Port" : "Sieve ataka",
    "Sieve credentials" : "Sieve kredentzialak",
    "IMAP credentials" : "IMAP kredentzialak",
    "Custom" : "Pertsonalizatua",
    "Sieve User" : "Sieve erabiltzailea",
    "Sieve Password" : "Sieve pasahitza",
    "Oh snap!" : "Hara!",
    "Save sieve settings" : "Gorde sieve ezarpenak",
    "The syntax seems to be incorrect:" : "Sintaxia baliogabea dirudi:",
    "Save sieve script" : "Gorde sieve scripta",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Zure sinadurak 2MB baino gehiago ditu. Honek editorearen errendimendua gutxitu dezake.",
    "Save signature" : "Gorde sinadura",
    "Place signature above quoted text" : "Jarri sinadura aipatutako testuaren gainean",
    "Message source" : "Mezuaren iturburua",
    "An error occurred, unable to rename the tag." : "Errore bat gertatu da, ezin izan zaio etiketa aldatu.",
    "Edit name or color" : "Editatu izena edo kolorea",
    "Delete tag" : "Ezabatu etiketa",
    "Set tag" : "Ezarri etiketa",
    "Unset tag" : "Ezarri gabeko etiketa",
    "Tag name is a hidden system tag" : "Etiketaren izena ezkutatutako sistema-etiketa da",
    "Tag already exists" : "Etiketa dagoeneko existitzen da",
    "Tag name cannot be empty" : "Etiketaren izena ezin da hutsik egon",
    "An error occurred, unable to create the tag." : "Errore bat gertatu da, ezin da etiketa sortu.",
    "Add default tags" : "Gehitu etiketa lehenetsiak",
    "Add tag" : "Gehitu etiketa",
    "Task created" : "Eginkizuna sortuta",
    "Could not create task" : "Ezin izan da eginkizuna sortu",
    "No calendars with task list support" : "Ez dago eginkizun-zerrendarik onartzen duen egutegirik",
    "Summarizing thread failed." : "Haria laburbiltzeak huts egin du.",
    "Could not load your message thread" : "Ezin izan da zure mezuen haria kargatu",
    "The thread doesn't exist or has been deleted" : "Haria ez da existitzen edo ezabatu egin da",
    "Loading thread" : "Haria kargatzen",
    "Not found" : "Ez da aurkitu",
    "Encrypted & verified " : "Enkriptatuta eta egiaztatua",
    "Signature verified" : "Sinadura egiaztatua",
    "Signature unverified " : "Sinadura egiaztatu gabe",
    "This message was encrypted by the sender before it was sent." : "Mezu hau igorleak enkriptatu zuen bidali aurretik.",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Mezu honek S/MIME sinadura digital egiaztatua dauka. Mezua ez da aldatu bidali zenetik.",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Mezu honek egiaztatu gabeko S/MIME sinadura digital bat dauka. Baliteke mezua bidali zenetik aldatu izana edo sinatzailearen ziurtagiria fidagarria ez izatea.",
    "Reply all" : "Erantzun denei",
    "Unsubscribe request sent" : "Harpidetza kentze eskaera bidalita",
    "Could not unsubscribe from mailing list" : "Ezin izan da posta-zerrendako harpidetza kendu",
    "Disable reminder" : "Desgaitu gogorarazpena",
    "Unsubscribe" : "Harpidetza kendu",
    "Reply to sender only" : "Erantzun bakarrik igorleari",
    "Mark as unfavorite" : "Markatu ez gogoko gisa",
    "Mark as favorite" : "Markatu gogoko gisa",
    "Unsubscribe via link" : "Harpidetza kendu esteka bidez",
    "Unsubscribing will stop all messages from the mailing list {sender}" : "Harpidetza kentzeak {sender} posta-zerrendako mezu guztiak geldituko ditu",
    "Send unsubscribe email" : "Bidali harpidetza kentzeko mezu elektronikoa",
    "Unsubscribe via email" : "Harpidetza kendu mezu elektroniko bidez",
    "{name} Assistant" : "{name} laguntzailea",
    "Thread summary" : "Hariaren laburpena",
    "Go to latest message" : "Joan azken mezura",
    "The message could not be translated" : "Ezin izan da mezu hau itzuli",
    "Translation copied to clipboard" : "Itzulpena arbelera kopiatu da",
    "Translation could not be copied" : "Ezin izan da itzulpena kopiatu",
    "Translate message" : "Itzuli mezua",
    "Translate from" : "Itzuli honetatik",
    "Translate to" : "Itzuli honetara",
    "Translating" : "Itzultzen",
    "Copy translated text" : "Kopiatu itzulitako testua",
    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Desgaitu zaborrontziaren atxikipena eremua hutsik utziz edo 0 moduan ezarriz. Zaborrontziaren atxikipena gaitu ondoren ezabatzen diren mezuak soilik prozesatuko dira.",
    "Could not remove trusted sender {sender}" : "Ezin izan da {sender} igorle fidagarria kendu",
    "No senders are trusted at the moment." : "Une honetan ez da igorle fidagarririk.",
    "Untitled event" : "Izenik gabeko gertaera",
    "(organizer)" : "(antolatzailea)",
    "Import into {calendar}" : "Inportatu {calendar} egutegira",
    "Event imported into {calendar}" : "Gertaera inportatu da {calendar} egutegira",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{flightNr} hegaldia {depAirport} aireportutik {arrAirport} aireportura",
    "Airplane" : "Hegazkina",
    "Reservation {id}" : "Erreserba {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} trena {depStation} geltokitik {arrStation} geltokira",
    "Train from {depStation} to {arrStation}" : "Trena {depStation} geltokitik {arrStation} geltokira",
    "Train" : "Trena",
    "Stop" : "Gelditu",
    "Delete action" : "Ezabatu ekintza",
    "Deleted" : "Ezabatuta",
    "Recipient" : "Hartzailea",
    "Delete filter" : "Ezabatu iragazkia",
    "Delete mail filter {filterName}?" : "Ezabatu {filterName} posta-iragazkia?",
    "Are you sure to delete the mail filter?" : "Ziur zaude posta-iragazkia ezabatu nahi duzula?",
    "New filter" : "Iragazki berria",
    "Filter saved" : "Iragazkia gordeta",
    "Could not save filter" : "Ezin izan da iragazkia gorde",
    "Filter deleted" : "Iragazkia ezabatuta",
    "Could not delete filter" : "Ezin izan da iragazkia ezabatu",
    "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "Kontrolatu zure posta elektronikoaren kaosa. Iragazkiek garrantzitsuena lehenestu eta zaborra ezabatzen laguntzen dizute.",
    "Filter is active" : "Iragazkia gaituta dago",
    "Filter is not active" : "Iragazkia desgaituta dago",
    "Help" : "Laguntza",
    "contains" : "dauka",
    "A substring match. The field matches if the provided value is contained within it. For example, \"report\" would match \"port\"." : "Azpikate bat etortzea. Eremua bat dator emandako balioa barruan badago. Adibidez, \"aireportua\" bat etorriko litzake \"portua\"-rekin.",
    "matches" : "bat dator",
    "A pattern match using wildcards. The \"*\" symbol represents any number of characters (including none), while \"?\" represents exactly one character. For example, \"*report*\" would match \"Business report 2024\"." : "Patroi bat etortzea komodinak erabiliz. «*» sinboloa edozein karaktere (ezer ez barne) kopuru adierazten du. Bestalde, «?» karaktere bakarra adierazten du. Adibidez «*txosten*» «2024ko txostena»-rekin bat etorriko litzateke.",
    "Actions" : "Ekintzak",
    "Priority" : "Lehentasuna",
    "Enable filter" : "Gaitu iragazkia",
    "Tag" : "Etiketa",
    "delete" : "ezabatu",
    "Edit" : "Editatu",
    "Successfully updated config for \"{domain}\"" : "\"{domain}\"-ren konfigurazioa behar bezala eguneratu da",
    "Error saving config" : "Errorea konfigurazioa gordetzean",
    "Saved config for \"{domain}\"" : "\"{domain}\"-ren konfigurazioa gorde da",
    "Could not save provisioning setting" : "Ezin izan da hornidura ezarpena gorde",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["{count} kontua behar bezala hornitu da.","{count} kontuak behar bezala hornitu dira."],
    "There was an error when provisioning accounts." : "Errore bat gertatu da kontuak hornitzean.",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "\"{domain}\"-ren kontuak behar bezala ezabatu dira.",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Errorea gertatu da \"{domain}\"-ren kontuak ezabatzean.",
    "Could not save default classification setting" : "Ezin izan da sailkapen-ezarpen lehenetsia gorde",
    "Mail app" : "Posta elektroniko aplikazioa",
    "The mail app allows users to read mails on their IMAP accounts." : "Posta elektroniko aplikazio honek aukera ematen die erabiltzaileei IMAP kontuetako mezuak irakurtzeko.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Hemen instantzia osoko ezarpenak aurkitu ditzakezu. Erabiltzailearen ezarpen espezifikoak aplikazioan bertan daude (beheko ezkerreko izkinan).",
    "Account provisioning" : "Kontu horniketa",
    "A provisioning configuration will provision all accounts with a matching email address." : "Hornidura konfigurazio batek kontu guztiak hornituko ditu helbide elektronikoarekin.",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Hornitze domeinuaren eremuan komodina (*)  erabilita erabiltzaile guztiei aplikatuko zaien konfigurazioa sortuko da, beste konfigurazio batekin bat ez datozenean.",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Hornidura mekanismoak domeinu konfigurazio zehatzak lehenetsiko ditu komodin-domeinuaren konfigurazioaren aurrean.",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Erabiltzailea dagoeneko beste konfigurazio batekin hornitu ondoren bat datorren konfigurazio berri bat aurkitzen bada, konfigurazio berriak izango du lehentasuna eta erabiltzaileari berriro hornituko zaio konfigurazioarekin.",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "Domeinu bakoitzeko konfigurazio bakarra egon daiteke eta komodin-domeinuaren konfigurazio bakarra.",
    "These settings can be used in conjunction with each other." : "Ezarpen hauek beste batzuekin batera erabili daitezke.",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "Bakarrik nahi baduzu erabiltzaile guztientzako domeinua hornitzea, erabili komodina (*).",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Ezarpen honek zentzua dauka zure Nextcloud eta mail zerbitzariek erabiltzaileen atzealde berdina erabiltzen badute zure erakundean.",
    "Provisioning Configurations" : "Horniketa konfigurazioak",
    "Add new config" : "Gehitu ezarpen berria",
    "Provision all accounts" : "Hornitu kontu guztiak",
    "Allow additional mail accounts" : "Onartu e-mail kontu gehigarriak",
    "Allow additional Mail accounts from User Settings" : "Onartu posta kontu gehigarriak erabiltzaile ezarpenetatik",
    "Enable text processing through LLMs" : "Gaitu testuen prozesamendua LLMen bidez",
    "The Mail app can process user data with the help of the configured large language model and provide assistance features like thread summaries, smart replies and event agendas." : "Posta aplikazioak erabiltzailearen datuak prozesatu ditzake konfiguratutako hizkuntza-ereduaren laguntzaz eta laguntza-funtzioak eskain ditzake, hala nola harien laburpenak, erantzun adimendunak eta gertaeren agendak.",
    "Enable LLM processing" : "Gaitu LLM prozesatzea",
    "Enable classification by importance by default" : "Gaitu garrantziaren araberako sailkapena modu lehenetsian",
    "The Mail app can classify incoming emails by importance using machine learning. This feature is enabled by default but can be disabled by default here. Individual users will still be able to toggle the feature for their accounts." : "Posta aplikazioak sarrerako mezu elektronikoak garrantziaren arabera sailka ditzake ikaskuntza automatikoa erabiliz. Ezaugarri hau lehenespenez gaituta dago, baina lehenespenez desgaitu daiteke hemen. Erabiltzaile indibidualek beren kontuetarako funtzioa aldatzeko aukera izango dute oraindik.",
    "Enable classification of important mails by default" : "Gaitu mezu garrantzitsuen sailkapena modu lehenetsian",
    "Anti Spam Service" : "Anti spam zerbitzua",
    "You can set up an anti spam service email address here." : "Hemen spamaren aurkako zerbitzuaren helbide elektronikoa konfigura dezakezu.",
    "Any email that is marked as spam will be sent to the anti spam service." : "Spam gisa markatutako edozein mezu elektroniko spamaren aurkako zerbitzura bidaliko da.",
    "Gmail integration" : "Gmail integrazioa",
    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail-ek erabiltzaileei euren posta elektronikora sartzeko baimena ematen die IMAP bidez. Segurtasun arrazoiengatik sarbide hori soilik da posible OAuth 2.0 konexio batekin edo bi faktoreko autentifikazioa eta aplikazioen pasahitzak erabiltzen diren Google kontuekin.",
    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "\"Web aplikazio\" baterako bezero ID berri bat erregistratu behar duzu Google Cloud kontsolan. Gehitu {url} URLa baimendutako birbideratze URI gisa.",
    "Microsoft integration" : "Microsoft integrazioa",
    "Successfully set up anti spam email addresses" : "Konfiguratu spamaren aurkako helbide elektronikoak",
    "Error saving anti spam email addresses" : "Errorea spamaren aurkako helbide elektronikoak gordetzean",
    "Successfully deleted anti spam reporting email" : "Spamaren aurkako jakinarazpen mezu elektronikoa behar bezala ezabatu da",
    "Error deleting anti spam reporting email" : "Errorea spamaren aurkako jakinarazpen mezu elektronikoa ezabatzean",
    "Anti Spam" : "Spamaren aurkakoa",
    "Add the email address of your anti spam report service here." : "Gehitu hemen spamaren aurkako jakinarazpen-zerbitzuaren helbide elektronikoa .",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Ezarpen hau erabiltzean, jakinarazpen-mezu elektroniko bat bidaliko zaio SPAM jakinarazpen-zerbitzariari erabiltzaile batek \"Markatu spam gisa\"-n klik egiten duenean.",
    "The original message will be attached as a \"message/rfc822\" attachment." : "Jatorrizko mezua \"message/rfc822\" eranskin gisa erantsiko da.",
    "\"Mark as Spam\" Email Address" : "\"Markatu Spama gisa\" helbide elektronikoa",
    "\"Mark Not Junk\" Email Address" : "\"Markatu mezu ez-baztergarri gisa\" helbide elektronikoa",
    "Reset" : "Berrezarri",
    "Google integration configured" : "Google integrazioa konfiguratu da",
    "Could not configure Google integration" : "Ezin izan da Google integrazioa konfiguratu",
    "Google integration unlinked" : "Desestekatu da Google-ren integrazioa",
    "Could not unlink Google integration" : "Ezin izan da desestekatu Google integrazioa",
    "Client ID" : "Bezeroaren IDa",
    "Client secret" : "Bezeroaren sekretua",
    "Unlink" : "Deskonektatu",
    "Microsoft integration configured" : "Microsoft integrazioa konfiguratu da",
    "Could not configure Microsoft integration" : "Ezin izan da Microsoft integrazioa konfiguratu",
    "Microsoft integration unlinked" : "Microsoft integrazioa desestekatu da",
    "Could not unlink Microsoft integration" : "Ezin izan da desestekatu Microsoft integrazioa",
    "Tenant ID (optional)" : "Maizterraren ID (aukerakoa)",
    "Domain Match: {provisioningDomain}" : "Bat datorren domeinua: {provisioningDomain}",
    "Email: {email}" : "Posta helbidea: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} hemen: {host}:{port} ({ssl} encryption)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} hemen: {host}:{port} ({ssl} encryption)",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} {host}-en: {port} ({ssl} enkriptatzea)",
    "Configuration for \"{provisioningDomain}\"" : "\"{provisioningDomain}\"-ren konfigurazioa",
    "Provisioning domain" : "Domeinua hornitzen",
    "Email address template" : "E-postaren txantiloia",
    "IMAP" : "IMAP",
    "User" : "Erabiltzailea",
    "Host" : "Ostalaria",
    "Port" : "Ataka",
    "SMTP" : "SMTP",
    "Master password" : "Pasahitza nagusia",
    "Use master password" : "Erabili pasahitza nagusia",
    "Sieve" : "Sieve",
    "Enable sieve integration" : "Gaitu sieve integrazioa",
    "LDAP aliases integration" : "LDAP aliasen integrazioa",
    "Enable LDAP aliases integration" : "Gaitu LDAP ezizenen integrazioa",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "LDAP aliasen integrazioak konfiguratutako LDAP direktorioko atributu bat irakurtzen du posta elektroniko aliasak hornitzeko.",
    "LDAP attribute for aliases" : "Aliasentzako LDAP atributua",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Balio anitzeko atributu bat posta elektroniko aliasak hornitzeko. Balio bakoitzerako alias bat sortzen da. LDAP direktorioan ez dauden Nextcloud-en dauden aliasak ezabatzen dira.",
    "Save Config" : "Gorde konfigurazioa",
    "Unprovision & Delete Config" : "Ez hornitu eta ezabatu konfigurazioa",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% eta%EMAIL% erabiltzailearen UID eta e-postarekin ordeztuko dira",
    "With the settings above, the app will create account settings in the following way:" : "Goiko ezarpenekin, aplikazioak honako ezarpenak dituzten kontuak sortuko ditu:",
    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "Emandako PKCS #12 ziurtagiriak gutxienez izan behar ditu ziurtagiri bat eta gako pribatu bat zehazki.",
    "Failed to import the certificate. Please check the password." : "Ezin izan da ziurtagiria inportatu. Mesedez, egiaztatu pasahitza.",
    "Certificate imported successfully" : "Ziurtagiria ongi inportatu da",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Ezin izan da ziurtagiria inportatu. Mesedez, ziurtatu gako pribatua ziurtagiriarekin bat datorrela eta ez dagoela pasaesaldi batek babestuta.",
    "Failed to import the certificate" : "Ezin izan da ziurtagiria inportatu",
    "S/MIME certificates" : "S/MIME ziurtagiriak",
    "Certificate name" : "Ziurtagiriaren izena",
    "E-mail address" : "E-mail helbidea",
    "Valid until" : "Data hau arte baliogarria",
    "Delete certificate" : "Ezabatu ziurtagiria",
    "No certificate imported yet" : "Oraindik ez da inportatu ziurtagiririk",
    "Import certificate" : "Inportatu ziurtagiria",
    "Import S/MIME certificate" : "Inportatu S/MIME ziurtagiria",
    "PKCS #12 Certificate" : "PKCS #12 Ziurtagiria",
    "PEM Certificate" : "PEM Ziurtagiria",
    "Certificate" : "Ziurtagiria",
    "Private key (optional)" : "Gako pribatua (aukerakoa)",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Gako pribatua beharrezkoa da  soilik ziurtagiri hau erabiliz sinatutako eta enkriptatutako mezu elektronikoak bidaltzeko asmoa baduzu .",
    "Submit" : "Bidali",
    "Group" : "Taldea",
    "Shared" : "Partekatuta",
    "Shares" : "Partekatzeak",
    "Insert" : "Txertatu",
    "Account connected" : "Kontua konektatuta",
    "You can close this window" : "Leiho hau itxi dezakezu",
    "Connect your mail account" : "Konektatu zure posta kontua",
    "To add a mail account, please contact your administrator." : "E-mail kontua gehitzeko, kontaktatu zure administratzailearekin, mesedez.",
    "All" : "Denak",
    "Drafts" : "Zirriborroak",
    "Priority inbox" : "Lehentasuneko sarrera",
    "All inboxes" : "Postontzi guztiak",
    "Inbox" : "Sarrera-ontzia",
    "Junk" : "Zaborra",
    "Sent" : "Bidalia",
    "Trash" : "Zakarrontzia",
    "Connect OAUTH2 account" : "Konektatu OAUTH2 kontua",
    "Error while sharing file" : "Errorea fitxategia partekatzean",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["Mezu berri %n \njaso duzu {from} helbidetik","%n mezu berri \njaso dituzu {from} helbidetik"],
    "Nextcloud Mail" : "Nextcloud Posta",
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "Dagoeneko mezu bat prozesatzen ari da. Jarraitzen baduzu, gorde gabeko aldaketa guztiak galduko dira!",
    "Discard changes" : "Baztertu aldaketak",
    "Discard unsaved changes" : "Baztertu gorde gabeko aldaketak",
    "Keep editing message" : "Jarraitu mezua editatzen",
    "Attachments were not copied. Please add them manually." : "Ezin izan dira atxikitakoak kopiatu. Gehitu itzazu eskuz, mesedez.",
    "Could not create snooze mailbox" : "Ezin izan da geroko utzitakoen postontzia sortu",
    "Message sent" : "Mezua bidalita",
    "Could not send message" : "Ezin izan da mezua bidali",
    "Could not load {tag}{name}{endtag}" : "Ezin izan da {tag}{name}{endtag} kargatu",
    "There was a problem loading {tag}{name}{endtag}" : "Arazo bat egon da {tag}{name}{endtag} kargatzerakoan",
    "Could not load your message" : "Ezin izan da zure mezua kargatu",
    "Could not load the desired message" : "Ezin izan da kargatu nahi zen mezu hori",
    "Could not load the message" : "Ezin izan da mezua kargatu",
    "Error loading message" : "Errorea mezua kargatzerakoan",
    "Forwarding to %s" : "%s helbidera birbidaltzen",
    "Click here if you are not automatically redirected within the next few seconds." : "Egin klik hemen hurrengo segundoetan automatikoki birbideratzen ez bada.",
    "Redirect" : "Birbideratu",
    "The link leads to %s" : "Estekak hona bideratzen du: %s",
    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Orrialde hori bisitatu nahi ez baduzu, itzul dezakezu <a href=\"%s\">Mail </a>-ra.",
    "Continue to %s" : "Jarraitu hona: %s",
    "Mark all messages of this folder as read" : "Markatu karpeta honetako mezu guztiak irakurrita bezala",
    "Last 7 days" : "Azken 7 egunetan",
    "From me" : "Nigandik"
},
"nplurals=2; plural=(n != 1);");
